var searchData=
[
  ['manager',['Manager',['../classManager.html',1,'']]],
  ['menu_5fref',['Menu_Ref',['../classMenu__Ref.html',1,'']]],
  ['menu_5fref_5fsql',['Menu_Ref_sql',['../classMenu__Ref__sql.html',1,'Menu_Ref_sql'],['../classMenu__Ref__SQL.html',1,'Menu_Ref_SQL']]]
];
